==> haskell-regex-pcre-0.94.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-pcre
version: 0.94.4
id: regex-pcre-0.94.4-Jlv6hsCUeTALprorFmhYD6
key: regex-pcre-0.94.4-Jlv6hsCUeTALprorFmhYD6
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://hackage.haskell.org/package/regex-pcre
package-url: http://code.haskell.org/regex-pcre/
synopsis: Replaces/Enhances Text.Regex
description:
    The PCRE backend to accompany regex-base, see www.pcre.org
category: Text
abi: 7a9a71430d6234018f833829b7187f6a
exposed: True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap
import-dirs: /usr/lib/ghc-8.6.1/site-local/regex-pcre-0.94.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/regex-pcre-0.94.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/regex-pcre-0.94.4
hs-libraries: HSregex-pcre-0.94.4-Jlv6hsCUeTALprorFmhYD6
extra-libraries:
    pcre
depends:
    array-0.5.2.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    regex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
haddock-interfaces: /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html: /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-pcre-0.94.4-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-pcre
version: 0.94.4
id: regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
key: regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://hackage.haskell.org/package/regex-pcre
package-url: http://code.haskell.org/regex-pcre/
synopsis: Replaces/Enhances Text.Regex
description:
    The PCRE backend to accompany regex-base, see www.pcre.org
category: Text
abi: be34b12d125b72206576545bae09b25f
exposed: True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap
import-dirs: /usr/lib/ghc-8.6.2/site-local/regex-pcre-0.94.4
library-dirs: /usr/lib/ghc-8.6.2/site-local/regex-pcre-0.94.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/regex-pcre-0.94.4
hs-libraries: HSregex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
extra-libraries:
    pcre
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    regex-base-0.93.2-8QGsCbNNqfw1S2nCPh78l5
haddock-interfaces: /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html: /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
